@@ -10,12 +10,17 @@ from aiohttp import ClientResponse, ClientResponseError
 
 from .errors import BeatSaverAPIException, NotFoundException, ServerException
 from .models.enum.base_enum import BaseEnum
+from .version import __version__
 
 T = TypeVar('T')
+_logger = logging.getLogger(__name__)
 
 
 class HttpClient:
     MAX_TIMEOUT = 60
+    _headers = {
+        'User-Agent': f'PyBeatSaver/{__version__}'
+    }
 
     def __init__(self, loop: Optional[AbstractEventLoop] = None):
         self.loop = loop
@@ -23,7 +28,7 @@ class HttpClient:
 
     async def start(self):
         if self._aiohttp is None:
-            self._aiohttp = aiohttp.ClientSession(loop=self.loop, raise_for_status=True)
+            self._aiohttp = aiohttp.ClientSession(loop=self.loop, headers=self._headers, raise_for_status=True)
 
     async def close(self):
         if self._aiohttp is not None:
@@ -60,7 +65,7 @@ class HttpClient:
             if sleep > self.MAX_TIMEOUT:
                 sleep = 60
 
-            logging.warning(f"Request failed! Waiting {sleep} seconds...")
+            _logger.warning(f"[{status}] Request failed! Waiting {sleep} seconds...")
             await asyncio.sleep(sleep)
 
             retries += 1
